.. include:: ../README.rst
   :end-before: About

.. include:: ../README.rst
   :start-after: =====
   :end-before: Installation

.. toctree::
   :numbered:

   installation
   usage
   cliapi
   changes
   contributing
   license
   authors
